@@ -51,15 +51,12 @@
 
 /* COPYRIGHTS & NO_WARRANTY -- defined to make code below a little nicer to
    read */
-static const char* COPYRIGHTS = \
-"Copyright (C) 1999-2011 by Mark Simpson\n"
-"Copyright (C) 1997 by Thomas Boll (original code)";
-static const char* NO_WARRANTY = \
+static const char NO_WARRANTY[] = \
 "%s comes with ABSOLUTELY NO WARRANTY.\n"
 "You may redistribute copies of %s under the terms of the GNU General\n"
 "Public License.  For more information about these matters, see the file\n"
 "named COPYING.";
-static const char* USAGE = \
+static const char USAGE[] = \
 "-f FILE,--file=FILE     \tUse FILE as input ('-' == stdin)\n"
 "-C DIR, --directory=DIR \tUnpack files into DIR\n"
 "-x SIZE --maxsize=SIZE  \tLimit maximum size of extracted archive (bytes)\n"
@@ -253,7 +250,9 @@ parse_cmdline (int argc, char **argv,
 
         case 'V':
             fprintf (stderr, "%s\n", PACKAGE_STRING);
-            fprintf (stderr, COPYRIGHTS);
+            fprintf (stderr, 
+		     "Copyright (C) 1999-2014 by Mark Simpson\n"
+		     "Copyright (C) 1997 by Thomas Boll (original code)");
             fprintf (stderr, "\n");
             fprintf (stderr, NO_WARRANTY, PACKAGE_NAME, PACKAGE_NAME);
             fprintf (stderr, "\n");
