@@ -1,8 +1,7 @@
-/* -*- mode: c++ -*- */
 /*
  * path.h -- Utility functions for dealing with pathnames
  *
- * Copyright (C)1999, 2000, 2001, 2002 Mark Simpson <damned@world.std.com>
+ * Copyright (C)1999-2006 Mark Simpson <damned@theworld.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +26,9 @@
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-extern char *
-concat_fname (const char* fname1, const char* fname2);
+extern char * concat_fname (const char* fname1, const char* fname2);
+extern char * munge_fname (const char *fname);
+extern char * find_free_number (const char *fname);
+extern int file_exists (const char *fname); /* 1 = true, 0 = false */
 
 #endif /* !PATH_H */
