@@ -1,8 +1,7 @@
-/* -*- mode: c++ -*- */
 /* 
  * tnef.h -- extract files from Microsoft TNEF format.
  * 
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 by Mark Simpson <damned@world.std.com>
+ * Copyright (C) 1999-2006 by Mark Simpson <damned@theworld.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,44 +24,15 @@
 #ifndef TNEF_H
 #define TNEF_H
 
+#if HAVE_CONFIG_H
+#  include "config.h"
+#endif /* HAVE_CONFIG_H */
+
+#include "common.h"
+
 /* TNEF signature.  Equivalent to the magic cookie for a TNEF file. */
 #define TNEF_SIGNATURE   0x223e9f78
 
-/* Object types */
-#define LVL_MESSAGE      0x01
-#define LVL_ATTACHMENT   0x02
-
-/* Defines uint[8,16,32] */
-#include "sizes.h"
-
-/* Generated list of attribute types/sizes */
-#include "tnef_types.h"
-#include "mapi_types.h"
-
-/* Generated list of attribute names */
-#include "tnef_names.h"
-#include "mapi_names.h"
-
-/* Store a date according to file specification */
-struct date
-{
-    int16 year, month, day;
-    int16 hour, min, sec;
-    int16 dow;
-};
-
-/* flags to modify behaviour of file parsing */
-enum { NONE    	= 0x000,
-       VERBOSE 	= 0x001,
-       DBG_OUT 	= 0x002,
-       LIST    	= 0x004,
-       PATHS   	= 0x008,
-       OVERWRITE= 0x010,
-       CONFIRM 	= 0x020,
-       NUMBERED = 0x040,
-       SAVEBODY = 0x080
-};
-
 /* Main entrance point to tnef processing */
 extern int
 parse_file(FILE *input, char * output_dir, 
