@@ -6,9 +6,9 @@ test=`echo $0 | sed -e 's/\(.*\)\..*/\1/' -e 's/^\.\///'`
 check_test_files () {
     for f in `cat datafiles/$test.list`
     do
-      check_test_full $srcdir/$test.dir/$f              \
-                      $srcdir/baselines/$f.baseline     \
-                      $srcdir/$f.diff
+      check_test_full "$srcdir/$test.dir/$f"              \
+                      "$srcdir/baselines/$f.baseline"     \
+                      "$srcdir/$f.diff"
     done
 }
 
